==> v0.55.0.zip: opentelemetry-js/packages/opentelemetry-sdk-trace-base/src/index.ts <==
/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export { Tracer } from './Tracer';
export {
  BasicTracerProvider,
  EXPORTER_FACTORY,
  ForceFlushState,
  PROPAGATOR_FACTORY,
} from './BasicTracerProvider';
export { BatchSpanProcessor, RandomIdGenerator } from './platform';
export { ConsoleSpanExporter } from './export/ConsoleSpanExporter';
export { InMemorySpanExporter } from './export/InMemorySpanExporter';
export { ReadableSpan } from './export/ReadableSpan';
export { SimpleSpanProcessor } from './export/SimpleSpanProcessor';
export { SpanExporter } from './export/SpanExporter';
export { NoopSpanProcessor } from './export/NoopSpanProcessor';
export { AlwaysOffSampler } from './sampler/AlwaysOffSampler';
export { AlwaysOnSampler } from './sampler/AlwaysOnSampler';
export { ParentBasedSampler } from './sampler/ParentBasedSampler';
export { TraceIdRatioBasedSampler } from './sampler/TraceIdRatioBasedSampler';
export { Sampler, SamplingDecision, SamplingResult } from './Sampler';
export { Span } from './Span';
export { SpanProcessor } from './SpanProcessor';
export { TimedEvent } from './TimedEvent';
export {
  BatchSpanProcessorBrowserConfig,
  BufferConfig,
  GeneralLimits,
  SDKRegistrationConfig,
  SpanLimits,
  TracerConfig,
} from './types';
export { IdGenerator } from './IdGenerator';

==> v2.0.1.zip: opentelemetry-js/packages/opentelemetry-sdk-trace-base/src/index.ts <==
/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export { BasicTracerProvider } from './BasicTracerProvider';
export { BatchSpanProcessor, RandomIdGenerator } from './platform';
export { ConsoleSpanExporter } from './export/ConsoleSpanExporter';
export { InMemorySpanExporter } from './export/InMemorySpanExporter';
export { ReadableSpan } from './export/ReadableSpan';
export { SimpleSpanProcessor } from './export/SimpleSpanProcessor';
export { SpanExporter } from './export/SpanExporter';
export { NoopSpanProcessor } from './export/NoopSpanProcessor';
export { AlwaysOffSampler } from './sampler/AlwaysOffSampler';
export { AlwaysOnSampler } from './sampler/AlwaysOnSampler';
export { ParentBasedSampler } from './sampler/ParentBasedSampler';
export { TraceIdRatioBasedSampler } from './sampler/TraceIdRatioBasedSampler';
export { Sampler, SamplingDecision, SamplingResult } from './Sampler';
export { Span } from './Span';
export { SpanProcessor } from './SpanProcessor';
export { TimedEvent } from './TimedEvent';
export {
  BatchSpanProcessorBrowserConfig,
  BufferConfig,
  GeneralLimits,
  SDKRegistrationConfig,
  SpanLimits,
  TracerConfig,
} from './types';
export { IdGenerator } from './IdGenerator';
